Samples

Enum Samples 

pub enum Samples {
    F64(Vec<f64>),
    F32(Vec<f32>),
    I32(Vec<i32>),
    U32(Vec<u32>),
    I24(Vec<I24>),
    U24(Vec<U24>),
    I16(Vec<i16>),
    U16(Vec<u16>),
    I8(Vec<i8>),
    U8(Vec<u8>),
}

Variants



F64(Vec<f64>)



F32(Vec<f32>)



I32(Vec<i32>)



U32(Vec<u32>)



I24(Vec<I24>)



U24(Vec<U24>)



I16(Vec<i16>)



U16(Vec<u16>)



I8(Vec<i8>)



U8(Vec<u8>)

Implementations

Source

impl Samples

pub const fn empty(format: Format) -> Self

pub fn equilibrium(format: Format, len: usize) -> Self

Create a new Samples filled with len amount of equilibrium samples (silence)

pub fn with_capacity(format: Format, capacity: usize) -> Self

pub fn len(&self) -> usize

Returns the amount of samples in the buffer

pub fn is_empty(&self) -> bool

pub fn format(&self) -> Format

Returns the sample format of the buffer

pub fn as_bytes(&self) -> &[u8]

pub fn from_ne_bytes(format: Format, bytes: &[u8]) -> Self

pub fn from_be_bytes(format: Format, bytes: &[u8]) -> Self

pub fn from_le_bytes(format: Format, bytes: &[u8]) -> Self

pub fn into_samples<S: Sample>(self) -> Vec<S>

Returns self in a vector of the provided sample type

pub fn to_samples<S: Sample>(&self) -> Vec<S>

Creates a copy of the samples in the given format