pub struct SampleRate(pub u32);Tuple Fields
0: u32Implementations
Sourceimpl SampleRate
impl SampleRate
Sourcepub fn duration_for_samples(self, len: usize) -> Duration
pub fn duration_for_samples(self, len: usize) -> Duration
Calculate the duration for the given amount of samples (per channel)
Sourcepub const fn common() -> &'static [SampleRate]
pub const fn common() -> &'static [SampleRate]
List of common sample rates encountered in the wild
pub fn any() -> ValueRange<Self>